#----------------------------------------------------------
# Analyze CPUE per area from DATRAS.ICES.dk
#----------------------------------------------------------
rm(list=ls(all=TRUE)) # clear previous variables etc
options(digits=3) # displays all numbers with three significant digits as default
graphics.off() # close graphics windows from previous sessions

# Set defaults vor variables that can be provided by the user
StartYear     <- NA   # exclude starting years without data
EndYear       <- 2011 # last year in DATRAS unreliable
Area          <- "All"
Subarea       <- NA
FB_Lmax       <- 1000 # max known length in cm
user.Lv       <- NA   # set length at full selection
Lm90          <- NA      
user.SSB.lim  <- NA   # set SSB.lim
t.rec         <- NA # set years between recruits and spawners 
Species       <- NA
a             <- 0.01
b             <- 3
M             <- 0.2

# select data
#-----------------------------------------
# Joint file for standard North Sea species
#-----------------------------------------
 File     <- "CPUE_Area1-7_2012_1Q_StdSp.csv"

# Species  <- "Clupea harengus" # NS Herring
# StartYear  <- 1970
# Area       <- c(1,2,3,4,5,6,7) 
# Subarea    <- 6
# Linf       <- 35.9 
# K          <- 0.35 
# t0         <- -0.45
# Lm50       <- 24.1 
# Lm90       <- 27.3
# a          <- 0.00322 
# b          <- 3.22 
# M          <- 0.35

 Species  <- "Gadus morhua" # NS Cod
 StartYear <- 1970
 Area    <- c(2,3,4) 
 Subarea <- 6
 Linf    <- 116 
 K       <- 0.21 
 t0      <- 0.18 
 Lm50    <- 43.5 
 a       <- 0.00587 
 b       <- 3.14 
 M       <- 0.26

# Species  <- "Melanogrammus aeglefinus" # NS Haddock
# StartYear <- 1970
# Area    <- c(1,2,3,4,7) 
# Subarea <- 6
# Linf    <- 62 
# K       <- 0.14 
# t0      <- -1.9 
# Lm50    <- 24.4 
# a       <- 0.00655 
# b       <- 3.1
 

# Species  <- "Merlangius merlangus" # NS Whiting
# StartYear <- 1990
# Area    <- c(1,2,3,4,5,6,7) 
# Subarea <- 6
# Linf    <- 59.1 
# K       <- 0.11 
# t0      <- -2 
# Lm50    <- 19.4 
# a       <- 0.00504 
# b       <- 3.14

# Species  <- "Pleuronectes platessa" # NS Plaice 
# Area     <- c(1,2,3,4,5,6,7) 
# Subarea  <- 6
# StartYear <- 1970
# Linf      <- 48 
# K         <- 0.16 
# t0        <- -1 
# Lm50      <- 21.1 
# Lm90      <- 27.3 
# a         <- 0.01 
# b         <- 2.98 
# M         <- 0.1

# Species <- "Pollachius virens" # NS Saithe
# StartYear <- 1980
# Area    <- c(1,2,3,4,5,6,7) 
# Linf    <- 126 
# K       <- 0.089 
# t0      <- -0.87
# Lm50    <- 44.6 
# a       <- 0.00442 
# b       <- 3.18
# M       <- 0.2

# Species  <- "Scomber scombrus" # NS Mackerel
# StartYear <- 1980
# Area    <- c(1,2,3,4,5,6,7)  
# Subarea <- 6
# Linf    <- 42.6 
# K       <- 0.28 
# t0      <- -1.3 
# Lm50    <- 24.7 
# Lm90    <- 27.2
# a       <- 0.00268 
# b       <- 3.32 

# Species  <- "Sprattus sprattus" # NS Sprat
# Area    <- c(1,2,3,4,5,6,7)
# Subarea <- 6
# FB_Lmax <- 18
# StartYear <- 1970
# Linf    <- 15 
# K       <- 0.5 
# t0      <- -0.49 
# Lm50    <- 7.49 
# Lm90    <- 9.25
# a       <- 0.00289 
# b       <- 3.36
# M       <- 0.38 # same as Baltic

# Species  <- "Trisopterus esmarkii" # NS Norway pout
# StartYear <- 1980
# Area    <- c(1,2,3,4,7) 
# Subarea <- 6
# Linf    <- 24.5 
# K         <- 0.39 
# t0        <- -0.67 
# Lm50    <- 11.8 
# a       <- 0.00618 
# b       <- 3.06 

#-----------------------------------------------------------------------------
# below are stocks with their own File, make sure NS File in line 20 is commented out 
# ----------------------------------------------------------------------------

# File <- "CPUE_sol-nsea-2012_1Q.csv"
# Area      <- c(1,2,3,4,5,6,7) 
# Subarea   <- 6
# StartYear <- 1985
# Linf      <- 40 
# K         <- 0.15 
# t0        <- -3 
# Lm50      <- 18.8 
# Lm90      <- 24.2 
# a         <- 0.00497 
# b         <- 3.2 


# File <- "CPUE_Area_dab_nsea-2012_1Q.csv"
# StartYear <- 1970
# Area  <- c(1,2,3,4,5,6,7)
# Subarea <- 6
# FB_Lmax <- 44
# Linf  <- 33
# K     <- 0.21 
# t0    <- -0.89 
# Lm50  <- 15
# Lm90  <- 18
# a     <- 0.0068
# b     <- 3.14

# File      <- "CPUE_Area_dab_balt_-2012_1Q.csv"
# Subarea   <- c(22,24)
# Linf      <- 37.7 
# K         <- 0.25 
# t0        <- -0.4 
# Lm50      <- 14.8
# Lm90      <- 17.4
# a         <- 0.00545 
# b         <- 3.23 

# File <- "AnguillaAll.csv"
# Subarea <- c(6, 22, 24)
# StartYear <- 1993
# Linf <- 83.2
# K    <- 0.08
# t0   <- 0
# Lm50 <- 60
# a    <- 0.0008
# b    <- 3.2

# File <- "SpurdogAll.csv"
# Subarea <- 6
# StartYear <- 1986
# t.rec <- 3 # includes pregnancy
# user.SSB.lim <- 23
# Linf <- 101
# K    <- 0.11
# t0   <- -3.6
# Lm50 <- 70
# a    <- 0.0032
# b    <- 3.07
# M    <- 0.1

# File <- "CPUE_Area_22_24_cod-balt_-2012_1Q.csv"
# Area <- c(22,24)
# Subarea <- c(22,24)
# StartYear <- 1995
# Linf <- 119
# K    <- 0.15 
# t0   <- -0.15 
# Lm50 <- 29
# Lm90 <- 35.6
# a    <- 0.00669
# b    <- 3.1
# M    <- 0.2

# File      <-"CPUE_Area_25-29_EB-cod-2012_1Q.csv"
# Area      <- c(25,26,27,28,29) 
# Subarea   <- 25
# Linf      <- 115 
# K         <- 0.11 
# t0        <- -0.078 
# Lm50      <- 32.2 
# a         <- 0.00743 
# b         <- 3.06 

# File      <- "CPUE_Area_NS-turbot-2012_1Q.csv"
# Subarea   <- 6
# StartYear <- 1980
# Linf      <- 60.2 
# K         <- 0.19 
# t0        <- -1.6 
# Lm50      <- 28 
# a         <- 0.00802 
# b         <- 3.26 
# M         <- 0.1 

# File      <- "CPUE_tur-balt-2012_All.csv"
# Area      <- c(22,23,24,25,26,27,28,29,30,31,32)
# Subarea   <- c(22,24)
# StartYear <- NA
# Linf      <- 50 
# K         <- 0.12 
# t0        <- -3 
# Lm50      <- 18.9
# Lm90      <- 23
# a         <- 0.0179 
# b         <- 3.02 
# M         <- 0.1 

# File      <- "CPUE_Area_fle-balt-2012_1Q.csv"
# Subarea   <- c(22,24)
# FB_Lmax   <- 60
# Linf      <- 48 
# K         <- 0.14 
# t0        <- -1.6 
# Lm50      <- 19.8
# Lm90      <- 23.1
# a         <- 0.00667 
# b         <- 3.18 

# File <- "CPUE_Area_fle_nsea-2012_1Q.csv"
# Area      <- c(1,2,3,4,5,6,7) 
# Subarea   <- 6
# StartYear <- 1975
# Linf      <- 40.8 
# K         <- 0.36 
# t0        <- -0.25 
# Lm50      <- 21 
# a         <- 0.00867 
# b         <- 3.06 

# File      <- "CPUE_Area_her-balt-2012_1Q.csv"
# Area      <- c(22,23,24) 
# Subarea   <- c(22,24)
# Linf      <- 30 
# K         <- 0.33 
# t0        <- -0.88 
# Lm50      <- 22.1
# Lm90      <- 28.3
# a         <- 0.00215 
# b         <- 3.35 

# File     <- "CPUE_spr-balt-2012_1Q.csv"
# Area     <- c(22,23,24,25,26,27,28,29,30,31,32)
# Subarea  <- c(22,24)
# StartYear <- 1997
# FB_Lmax   <- 18
# Linf      <- 15.5 
# K         <- 0.28 
# t0        <- -2.4 
# Lm50      <- 8.13
# Lm90      <- 11.2
# a         <- 0.00377
# b         <- 3.2 

# File      <- "CPUE_Area_ple-balt-2012_1Q.csv"
# Area      <- c(21,22,23) 
# StartYear <- 1996
# Subarea   <- c(22)
# Linf      <- 52 
# K         <- 0.17 
# t0        <- -0.72 
# Lm50      <- 21.1 # from North Sea
# Lm90      <- 27.3 # from North Sea
# a         <- 0.0101 
# b         <- 3 
# M         <- 0.1  # from North Sea

# File      <- "CPUE_Area_ple-balt-2012_1Q.csv"
# Area      <- c(24,25,26) # all subdivisions with data 
# StartYear <- 1995
# Subarea   <- 24
# Linf      <- 57 
# K         <- 0.15 
# t0        <- -0.87 
# Lm50      <- 20 
# Lm90      <- 23.4 
# a         <- 0.0123 
# b         <- 2.94 
# M         <- 0.1 # from North Sea

# File       <- "CPUE_Area_neph-nsea-2012_1Q.csv"
# Subarea    <- 6
# FB_Lmax     <- 11
# Linf       <- 9
# K          <- 0.1
# t0         <- 0
# Lm50       <- 3.5
# a          <- 0.58
# b          <- 3.1


# ----------------------------------------------------------------
# determine out-file
OutFile <- paste("Out_",File, sep="")
# read data
data.raw <- read.csv(File, header=T)

# select species
if(is.na(Species)==F) {
data.raw <- data.raw[data.raw$Species == Species,]
}

# since length and N are needed for all applications, exclude records where either is NA or zero
# or where length is larger than the maximum length recorded in FishBase (FB_Lmax)
data.raw <- data.raw[is.na(data.raw$LngtClas)==F & data.raw$LngtClas >=10 & data.raw$LngtClas < FB_Lmax*10,] 
data.raw <- data.raw[is.na(data.raw$CPUE_number_per_hour)==F & data.raw$CPUE_number_per_hour > 0,] 

# use StartYear and EndYear if given
if(is.na(StartYear)==F) {
  data.raw <- data.raw[data.raw$Year >=StartYear,] 
}
if(is.na(EndYear)==F) {
  data.raw <- data.raw[data.raw$Year <= EndYear,] 
}

# bind vectors into data frame
data.lw <- data.frame(Species=as.character(data.raw$Species), Year=as.numeric(data.raw$Year),
            Length=as.numeric(data.raw$LngtClas/10), N=as.numeric(data.raw$CPUE_number_per_hour),
            Area=data.raw$Area, stringsAsFactors=F) 

# restrict data to selected area
if(Area[1] != "All") {
  data.lw <- data.lw[data.lw$Area %in% Area,] 
} 

# determine number of areas for mean
Count.Areas    <- length(unique(data.lw$Area))
Count.Subareas <- length(Subarea)

#----------------------------------------------------
# Use LWR to get weight
#----------------------------------------------------
W.pr  <- a * data.lw$Length^b 
data.lw <- cbind(data.lw, Weight=W.pr)

# determine vectors 
Y    <- data.lw$Year
L    <- data.lw$Length
W    <- data.lw$Weight
N    <- data.lw$N # CPUE 
Area <- data.lw$Area

# -------------------------------------
# overall analysis
#--------------------------------------
Y.unique  <- sort(unique(Y)) # vector with years
mean.N   <- mean(by(N,Y,FUN=sum))
mean.W   <- mean(by((N*W),Y,FUN=sum))
# last 5 years analysis
Y.5      <- unique(Y[Y>(max(Y.unique)-5)])
N.5      <- by(N[Y>(max(Y.unique)-5)],Y[Y>(max(Y.unique)-5)], FUN=sum)
mean.N.5 <- mean(N.5)
mean.W.5 <- mean(by((N[Y>(max(Y.unique)-5)]*W[Y>(max(Y.unique)-5)]),Y[Y>(max(Y.unique)-5)],FUN=sum))
reg.5    <- lm(N.5 ~ Y.5) 
slope.N  <- reg.5$coefficients[2]
if(abs(slope.N)< 0.05 | summary(reg.5)$r.squared <0.1) {Trend <- "no trend"} else {
  ifelse(slope.N > 0, Trend <- "increasing", Trend <- "decreasing") }



#----------------------------------------------------------
# Determine length at full vulnerability by gear and recruit length
#----------------------------------------------------------
Lfreq     <- by(N,L,sum)
Lclas     <- sort(unique(L))
Lv        <- Lclas[which.max(Lfreq)]
L1.5      <- Linf*(1-exp(-K*(1.5-t0))) # get length at age 1.5 to determine recruits
Lr        <- ifelse(L1.5 >= Lv, L1.5, Lv)
tr        <- -log(1-Lr/Linf)/K+t0
tr        <- ifelse(tr < 1, 1, floor(tr))

#----------------------------------------------------------
# Prepare estimation of Z
#---------------------------------------------------------
# Select cohort of >= 1/3 Linf +/- 10% as range of initial cohort length
L0.mid     <- ifelse(1/3*Linf > 1.1*Lv, 1/3*Linf, 1.1*Lv)
half.range <- ifelse(0.1*L0.mid < 1, 1, ifelse(0.1*L0.mid < 2,2,3))
L0.low     <- floor(L0.mid-half.range)
L0.hi      <- ceiling(L0.mid+half.range)
# Determine mid age of cohort  
t0.mid     <- -log(1-L0.mid/Linf)/K+t0
# Get length range at age + 1
L1.mid  <- Linf*(1-exp(-K*(t0.mid+1-t0)))
L1.low  <- floor(L1.mid-half.range)
L1.hi   <- ceiling(L1.mid+half.range)
# Get length range at age + 2
L2.mid  <- Linf*(1-exp(-K*(t0.mid+2-t0)))
L2.low  <- floor(L2.mid-half.range)
L2.hi   <- ceiling(L2.mid+half.range)
# Get length range at age + 3
L3.mid  <- Linf*(1-exp(-K*(t0.mid+3-t0)))
L3.low  <- floor(L3.mid-half.range)
L3.hi   <- ceiling(L3.mid+half.range)

cat("\n")
cat("----------------------------------------------------","\n")
cat("Results of CPUE-per-Area analysis,", date(), "\n")
cat("----------------------------------------------------","\n")
cat("File =", File, "\n")
cat("Records with missing length or number of individuals were excluded. \n")
cat("Species =", as.character(data.lw$Species[1]), "\n")
cat("Years =", min(Y), " -", max(Y), "\n") 
cat("Area =", sort(unique(Area)), "\n")
cat("OutFile =",OutFile,"\n")
cat("Input Linf =", Linf,"(cm), LWR a =", a, ", b =", b,", M =", M, "\n")
cat("Maximum reported length =", max(L), "cm \n")
cat("Length of full selection by the gear Lv =", Lv, "cm  \n")
cat("Length at age 1.5 years L1.5 =", L1.5,"cm \n")
cat("Length where 50% of the females have reached maturity Lm50 =", Lm50, "\n")
cat("Length below which individuals are considered recruits Lr =",Lr,"cm \n")
cat("Age below which individuals are considered recruits tr =",tr,"years \n")
cat("Overall mean CPUE in numbers =", mean.N, "\n")
cat("Mean CPUE in numbers in last 5 years =", mean.N.5, "\n")
cat("Trend in abundance (N) in the last 5 years =", Trend, "\n")
cat("Overall mean CPUE in weight =", mean.W/1000, "(kg) \n")
cat("Mean CPUE in weight in last 5 years =", mean.W.5/1000, "\n\n")

#---------------------------------------------------------------
# Get annual catch per one hour of trawl
#---------------------------------------------------------------
cat("Catch per 1 hour trawling (N + W) \n")
cat("----------------------------------------\n")
cat("Year   MatN  TN   SSB  TSSB \n")
N.y.r.all   <- vector() # vector to capture number of recruits per year
N.y.all     <- vector() # vector to capture total number per year
N.y.m.all   <- vector() # vector to capture mature fish > Lm50
N.y.sub.all <- vector() # vector to capture numbers in Subarea
W.y.all     <- vector() # vector to capture total weight per year
W.y.m.all   <- vector() # vector to capture weight of mature fish > Lm50
Z.y.all     <- c(NA,NA,NA) # start filling in Z from fourth year onward


# loop through years 
for(y in Y.unique) {
  # get numbers and weights
  N.y        <- sum(N[Y==y])/Count.Areas
  N.y.all    <- append(N.y.all, N.y)
  N.y.m      <- sum(N[Y==y & L > Lr])/Count.Areas
  N.y.m.all  <- append(N.y.m.all, N.y.m)
  N.y.r      <- sum(N[Y==y & L<=Lr])/Count.Areas
  N.y.r.all  <- append(N.y.r.all, N.y.r)
  N.y.sub    <- ifelse(is.na(Subarea[1])==F,sum(data.raw$CPUE_number_per_hour[data.raw$Year==y & 
                       data.raw$Area %in% Subarea])/Count.Subareas,NA)
  N.y.sub.all<- append(N.y.sub.all, N.y.sub)
  W.y        <- sum(W[Y==y])/Count.Areas
  W.y.all    <- append(W.y.all, W.y)
  W.y.m      <- sum(W[Y==y & L > Lr])/Count.Areas
  W.y.m.all  <- append(W.y.m.all, W.y.m)
 
  # estimate Z over 3 subsequent years  
  # get numbers of cohort from this year and three subsequent years
  if(y <= (max(Y.unique)-3)) {
  Ncohort         <- c(sum(N[Y==y & L>=L0.low & L<=L0.hi])/Count.Areas,
                     ifelse(sum(N[Y==y+1 & L>=L1.low & L<=L1.hi])==0,0.0001,sum(N[Y==y+1 & L>=L1.low & L<=L1.hi])/Count.Areas),
                     ifelse(sum(N[Y==y+2 & L>=L2.low & L<=L2.hi])==0,0.0001,sum(N[Y==y+2 & L>=L2.low & L<=L2.hi])/Count.Areas),
                     ifelse(sum(N[Y==y+3 & L>=L3.low & L<=L3.hi])==0,0.0001,sum(N[Y==y+3 & L>=L3.low & L<=L3.hi]))/Count.Areas)
  Ycohort         <- c(y, y+1, y+2, y+3)
  logNcohort      <- log(Ncohort)
  # do linear regression to estimate Z from absolute slope of log-transformed numbers
  Regcohort       <- try(lm(logNcohort ~ Ycohort), silent=T)
  if("try-error" %in% class(Regcohort) || summary(Regcohort)$r.squared < 0.5) {Z.y <- NA} else {
  Z.y             <- abs(summary(Regcohort)$coefficients[2,1]) }
  Z.y.all         <- append(Z.y.all, Z.y)
  }
  
  # write results
  cat(y, "  ", format(N.y.m, digits=2),"  ", format(N.y, digits=2), "  ",  
       W.y.m/1000,"  ", W.y/1000, "\n") 
  out <- data.frame(y, N.y.m, N.y, W.y.m/1000, W.y/1000)
  write.table(out, OutFile, append=T, row.names=F, col.names=F, sep=",", dec=".")
} # end of annual loop

#---------------------------------------------
# Function to create three year moving average 
# with 2 year average for first and last year
#--------------------------------------------
mov3av <- function(x) {c(mean(c(x[1],x[2]),na.rm=T),filter(x, rep(1/3,3),
                          sides=2)[2:(length(x)-1)],
                         mean(c(x[length(x)], x[length(x)-1]), na.rm=T))
                       }
#create smoothed numbers
N.y.s.all   <- mov3av(N.y.all)
N.y.m.s.all <- mov3av(N.y.m.all)
N.y.r.s.all  <- mov3av(N.y.r.all)
N.y.sub.s.all<- mov3av(N.y.sub.all)
W.y.s.all   <- mov3av(W.y.all)/1000
W.y.m.s.all <- mov3av(W.y.m.all)/1000
Z.y.s.all   <- mov3av(Z.y.all)

#----------------------------------------
# Estimate stock-recruitment relationship
#----------------------------------------
t.rec         <- ifelse(is.na(t.rec)==F, t.rec, tr)
R            <- N.y.r.s.all[t.rec:length(Y.unique)] # number of recruits, omitting age of recruits
logR         <- log(R)
SSB          <- W.y.m.s.all[1:(length(Y.unique)-t.rec+1)] # weight of mature fish, in kg
Rinf         <- exp(mean(logR[which(SSB > (max(SSB) + min(SSB))/2 )])) # ignore SSB in lower half-range of SSB observations
n.Rinf       <- length(logR[which(SSB > (max(SSB) + min(SSB))/2)]) # n needed to calculate SE
SD.logRinf   <- sd(logR[which(SSB > (max(SSB) + min(SSB))/2)])
SE.logRinf   <- SD.logRinf/sqrt(n.Rinf)
LCL.Rinf     <- exp(log(Rinf)-1.96*SE.logRinf)
UCL.Rinf     <- exp(log(Rinf)+1.96*SE.logRinf)
if(is.na(user.SSB.lim)==T) {
  SSB.lim      <- min(SSB[which(R>=Rinf)]) # smallest SSB that created at least Rinf recruits
  LCL.SSB.lim  <- min(SSB[which(R >= LCL.Rinf)])
  UCL.SSB.lim  <- min(SSB[which(R >= UCL.Rinf)]) 
  if(UCL.SSB.lim==Inf || UCL.SSB.lim < 1.4 * SSB.lim) {
    SSB.pa     <- 1.4 * SSB.lim } else {SSB.pa <- UCL.SSB.lim }
} else {
SSB.lim      <- user.SSB.lim
SSB.pa       <- 1.4 * SSB.lim   
}
#---------------------------
# Plot results
#---------------------------

# plot length frequency histogram for checking
windows(8,6)
plot(x=Lclas, y=Lfreq, xlab="Length (cm)",ylab="Frequency",type="h", bty="l", log="y")
points(x=Lv, y=max(Lfreq), col="red")
abline(v=Lm50, lty=3)
text(x=Lm50, y=max(Lfreq), "Lm50", adj=c(-0.2,0))
abline(v=Lr, lty=3)
text(x=Lr, y=max(Lfreq), "Lr", adj=c(-0.4,0))
abline(v=2/3*Linf, lty=3)
text(x=2/3*Linf, y=max(Lfreq), "2/3 Linf", adj=c(-0.2,0))
abline(v=Linf, lty=3)
text(x=Linf, y=max(Lfreq), "Linf", adj=c(-0.2,0))

# plot 4 panel overview
windows(9,6)
par(mfrow=c(2,2))
# plot raw numbers
plot(x=Y.unique, y=N.y.all, type="l", ylim=c(0, max(N.y.all)), xlab="Year", bty="l",
     ylab="CPUE in raw numbers", lwd=3, main="DATRAS CPUE")
lines(x=Y.unique, y=N.y.m.all, col="red", lwd=2) 
abline(h=mean(N.y.all), lty=3, lwd=1.5)
text(x=Y.unique[1],y=mean(N.y.all), adj=c(0,-0.8), "Mean")

# plot smoothed recruits
plot(x=Y.unique, y=N.y.r.s.all, type="l", ylim=c(0, max(N.y.r.s.all, na.rm=T)), xlab="Year", bty="l",
     ylab="Young fish in smoothed numbers", lwd=3, main="Proxy Recruits")
abline(h=Rinf, lty=3, lwd=1.5)
text(x=Y.unique[1],y=Rinf, adj=c(0.15,-0.8), "proxy Rinf")

# plot smoothed Z
if(sum(Z.y.s.all,na.rm=T) > 0) {  # skip graph if no Z estimates
plot(x=Y.unique, y=Z.y.all, ylim=c(0, max(Z.y.all, na.rm=T)), type="l", bty="l", xlab="Year", 
     ylab="Total mortality Z (1/year)", main="Proxy Mortality")
lines(x=Y.unique, y=Z.y.s.all, type="b", lwd=3)
abline(h=2*M, lty=3, lwd=1.5)
abline(h=M, lty=5, lwd=1.5)
text(x=Y.unique[1],y=M, adj=c(0,-0.4), "M")
text(x=Y.unique[1],y=2*M, adj=c(0,-0.4), "F=M")
}

# plot smoothed weights = biomass 
Y.max <- ifelse(2.8*SSB.lim > max(W.y.m.s.all, na.rm=T), 3*SSB.lim, 1.1*max(W.y.m.s.all, na.rm=T))
plot(x=Y.unique, y=W.y.m.s.all, type="l", col="red", ylim=c(0, Y.max), xlab="Year", bty="l",
     ylab="CPUE in smoothed weight (kg)", lwd=3, main="Proxy Biomass")
abline(h=SSB.lim, lty=3, lwd=1.5)
abline(h=SSB.lim*1.4, lty=3, lwd=1.5, col="red")
abline(h=SSB.lim*2.8, lty=3, lwd=1.5, col="green")
text(x=Y.unique[1], y=SSB.lim, "proxy SSBlim", adj=c(0.1,-0.4))
text(x=Y.unique[1], y=SSB.lim*1.4, "proxy SSBpa", adj=c(0.1,-0.4))
text(x=Y.unique[1], y=SSB.lim*2.8, "proxy SSBmsy", adj=c(0.1,-0.4))

# plot stock-recruitment relationship
windows(6,4)
plot(x=SSB, y=R,  bty="l", xlim=c(0,ifelse(SSB.pa < max(SSB),max(SSB),SSB.pa)), ylim=c(0,max(R, na.rm=T)), 
     xlab="CPUE of mature fish (kg)", ylab="CPUE of young fish (n)", 
     main="")
lines(x=c(0,SSB.lim,ifelse(SSB.pa < max(SSB),max(SSB),SSB.pa)), y=c(0,Rinf, Rinf), lwd=1.5)
if(is.na(user.SSB.lim)==T) {
  lines(x=c(0,LCL.SSB.lim,ifelse(SSB.pa < max(SSB),max(SSB),SSB.pa)), y=c(0,LCL.Rinf,LCL.Rinf), lty=3)
  lines(x=c(0,UCL.SSB.lim,ifelse(SSB.pa < max(SSB),max(SSB),SSB.pa)), y=c(0,UCL.Rinf,UCL.Rinf), lty=3)
} else {
  lines(x=c(0,SSB.lim,ifelse(SSB.pa < max(SSB),max(SSB),SSB.pa)), y=c(0,LCL.Rinf,LCL.Rinf), lty=3)
  lines(x=c(0,SSB.lim,ifelse(SSB.pa < max(SSB),max(SSB),SSB.pa)), y=c(0,UCL.Rinf,UCL.Rinf), lty=3)
}
abline(v=SSB.lim, lty=5, lwd=1.5)
abline(v=SSB.pa, lty=5, lwd=1.5, col="red")
text(x=SSB.lim, y=0.95*max(R), "proxy SSBlim", adj=c(1.1,0))
text(x=SSB.pa, y=0.95*max(R), "SSBpa", adj=c(1.1,0), col="red")

# plot abundance in Subarea
if(is.na(Subarea[1])==F) {
  windows(6,4)
  # plot raw numbers
  plot(x=Y.unique, y=N.y.sub.all, type="l", ylim=c(0, max(N.y.sub.all, na.rm=T)), xlab="Year", bty="l",
       ylab="CPUE in numbers", main="")
  abline(h=mean(N.y.sub.all), lty=3, lwd=1.5)
  text(x=max(Y.unique),y=mean(N.y.sub.all), adj=c(0.6,-0.3), "Mean")
  lines(x=Y.unique, y=N.y.sub.s.all, lwd=3)
}

# plot score graph
windows(6,5)
plot(x=Y.unique, y=(2*M)/Z.y.s.all, ylim=c(0, 1.5), xlab="Year", 
     ylab="Score", type="l", bty="l", lwd=3, col="black")
abline(h=1, lty=3, lwd=1.5)
lines(x=Y.unique, y=W.y.m.s.all/(2.8*SSB.lim), lwd=3, col="red")

# write some numbers for easy capture, 5 year means
cat("Parameters \n")
cat("M      ", M,"\n")
cat("pSSBlim", SSB.lim, "\n")
cat("pSSBpa ", SSB.pa, "\n")
cat("pSSBmsy", 2 * SSB.pa, "\n")
cat("a      ", a, "\n")
cat("b      ", b, "\n")
cat("Linf   ", Linf, "\n")
cat("K      ", K, "\n")
cat("t0     ", t0, "\n")
cat("Lm50   ", Lm50, "\n")
cat("Lm90   ", Lm90, "\n")
cat("Mean Scores in last 5 years 2007-2011 \n")
cat("pSSB/pSSBmsy ", format(mean((W.y.m.all[Y.unique > (max(Y.unique)-5)]/1000) / (2 * SSB.pa)),digits=2), "\n" )
cat("2M / Z      ", 
    ifelse(length(Z.y.all[Y.unique > max(Y.unique)-5 & is.na(Z.y.all)==F & Z.y.all >= M]) > 2,
      format(mean((2*M) / (Z.y.all[Y.unique > (max(Y.unique)-5)]), na.rm=T ),digits=2),
      NA),"\n")
cat("EEZ abundance", ifelse(mean(N.y.sub.all[Y.unique > (max(Y.unique)-5)]) / mean(N.y.sub.all) > 1,"above","below" ),"\n")
reg.sub.5    <- lm(N.y.sub.all[Y.unique > (max(Y.unique)-5)] ~ Y.unique[Y.unique > (max(Y.unique)-5)]) 
slope.sub.N  <- reg.sub.5$coefficients[2]
if(abs(slope.sub.N)< 0.05 | summary(reg.sub.5)$r.squared <0.1) {sub.Trend <- "horizontal"} else {
  ifelse(slope.sub.N > 0, sub.Trend <- "increasing", sub.Trend <- "decreasing") }
cat("EEZ slope", sub.Trend, "\n")
cat("Median alpha =", median(N.y.r.all/N.y.m.all), "\n" )
cat("Median SSB/recruit = ", median(W.y.m.all/N.y.r.all), "g\n\n")
cat("Ingnore warning about Inf, if any \n")

